% fig_03_12
% plot the circular helix with moving trihedron 
% equation (3.47) for unit binormal vector

clear all, clf % initialize memory and figure
a = 1; b = 1/(2*pi); % radius and pitch of helix
d = 1/(sqrt(a^2 + b^2)); % common term for components
S = linspace(0,4*pi,100); % vector of natural parameter values
X = a*cos(d*S); % x-component of vector function for curve
Y = a*sin(d*S); % y-component
Z = b*d*S; % z-component
plot3(X,Y,Z,'k') % plot the helix
axis equal, grid on, box on, hold on 
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')

S = linspace(0,4*pi,9); % vector of natural parameter values
X = a*cos(d*S); % x-component of vector function for curve
Y = a*sin(d*S); % y-component
Z = b*d*S; % z-component
TX = -a*d*sin(d*S); % x-component of tangent vector
TY = a*d*cos(d*S); % y-component
TZ = b*d; % z-component
quiver3(X,Y,Z,TX,TY,TZ,0.5,'r') % plot tangent vectors (green)

KX = -a*d*d*cos(d*S); % x-component of curvature vector
KY = -a*d*d*sin(d*S); % y-component
KZ = 0; % z-component
quiver3(X,Y,Z,KX,KY,KZ,0.5,'g') % plot curvature vectors (red)

BX = b*d*sin(d*S); % x-component of binormal vector
BY = -b*d*cos(d*S); % y-component
BZ = a*d; % z-component
quiver3(X,Y,Z,BX,BY,BZ,0.5,'b') % plot binormal vectors (blue)
