% fig_03_17
% plot elliptic paraboloid
% equation (3.60)

clear all, clf reset % initialize memory and figure
u = linspace(-1,1,21); % vector of u-coords on parameter plane
v = linspace(-1,1,21); % vector of v-coords on parameter plane
[U,V]=meshgrid(u,v); % grid of points on parameter plane
SX = U; % x-component of vector function for surface, s=f(u,v)
SY = V; % y-component of s=f(u,v)
SZ = U.^2 + V.^2; % z-component of s=f(u,v)

% plot surface as wire-frame with color fill
surf(SX,SY,SZ) 
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('surface plot: elliptic paraboloid'), axis equal

% plot contour map with color fill
figure, contourf(SX,SY,SZ,10) 
colorbar, title('contour plot: elliptic paraboloid')
axis equal, axis tight
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')

NX = 1; NY = 0; NZ = 2*U; % components of tangent to u-parameter curves
figure, quiver3(SX,SY,SZ,NX,NY,NZ), hold on % plot tangent vectors
NX = 0; NY = 1; NZ = 2*V; % components of tangent to v-parameter curves
quiver3(SX,SY,SZ,NX,NY,NZ), axis equal % plot tangent vectors
title('quiver plot: tangent vectors to elliptic paraboloid')
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')

figure, mesh(SX,SY,SZ) % mesh plot: wire-frame
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('mesh plot: elliptic paraboloid with normals'), axis equal, hold on
D = sqrt(1+4*U.^2+4*V.^2); % absolute value of cross product of tangents
NX = -2*U./D; NY = -2*V./D; NZ = 1./D; % components of unit normal vector
quiver3(SX,SY,SZ,NX,NY,NZ) % plot unit normal vectors

figure, surfnorm(SX,SY,SZ) % surface normal plot: 
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('elliptic paraboloid with normals'), axis equal

figure, plot(u,SZ(18,1:21)) %plot u-parameter curve c(u,0.7)
xlabel('x-axis'), ylabel('z-axis')
title('u-parameter curve on elliptic paraboloid, v = 0.7')
axis equal, axis([-1 1 0 2])