% fig_03_19
% plot tangent and normal vectors to elliptic paraboloid
% equations (3.72) and (3.75)

clear all, clf reset % initialize memory and figure
u = linspace(-1,1,21); % vector of u-coords on parameter plane
v = linspace(-1,1,21); % vector of v-coords on parameter plane
[U,V]=meshgrid(u,v); % grid of points on parameter plane
SX = U; % x-component of vector function for surface, s=f(u,v)
SY = V; % y-component of s=f(u,v)
SZ = U.^2 + V.^2; % z-component of s=f(u,v)

% plot tangent vectors to u-parameter curves
NX = 1; NY = 0; NZ = 2*U;
quiver3(SX,SY,SZ,NX,NY,NZ), hold on

% plot tangent vectors to v-parameter curves
NX = 0; NY = 1; NZ = 2*V; 
quiver3(SX,SY,SZ,NX,NY,NZ), axis equal

% plot unit normal vectors to the surface
D = sqrt(1+4*U.^2+4*V.^2); % absolute value of cross product of tangents
NX = -2*U./D; NY = -2*V./D; NZ = 1./D; % components of normal vector
quiver3(SX,SY,SZ,NX,NY,NZ)
title('tangent and normal vectors to elliptic paraboloid')
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')