% fig_03_21
% plot helicoid with unit normal vectors
% equations (3.77) and (3.79)

clear all, clf reset % initialize memory and figure
c = 1;
u = linspace(-1,1,20); % vector of u-coords on parameter plane
v = linspace(0,pi/2,18); % vector of v-coords on parameter plane
[U,V]=meshgrid(u,v); % grid of points on parameter plane
SX = U.*cos(V); % x-component of vector function for surface, s=f(u,v)
SY = U.*sin(V); % y-component of s=f(u,v)
SZ = c*V; % z-component of s=f(u,v)

colormap (white);
surf(SX,SY,SZ) % surface plot: wire-frame with white color fill
xlabel('x-axis'), ylabel('y-axis'), zlabel('z-axis')
title('surface plot: helicoid with unit normals')
axis equal, hold on

D = sqrt(c^2+U.^2); % common denominator
NX = c*sin(V)./D; % x component of unit normal vector
NY = -c*cos(V)./D; % y component
NZ = U./D; % z component
quiver3(SX,SY,SZ,NX,NY,NZ) % plot unit normal vectors on wireframe